from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setup(
    name="bangla-text-normalizer",
    version="0.1.1",
    author="Nahid Ahsan",
    author_email="nahidahsan74@gmail.com",
    description="A robust text normalizer tool for Bangla language",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://gitlab.com/nahidahsan74/bangla-text-normalizer",
    project_urls={
        "Documentation": "https://gitlab.com/nahidahsan74/bangla-text-normalizer/-/blob/main/README.md",
        "Source": "https://gitlab.com/nahidahsan74/bangla-text-normalizer",
        "Tracker": "https://gitlab.com/nahidahsan74/bangla-text-normalizer/-/issues",
    },
    packages=find_packages(),
    keywords=[
        "bangla", "bengali", "text-normalizer", "normalization", 
        "nlp", "natural-language-processing", "tts", "text-to-speech", 
        "num2words", "bangla-nlp"
    ],
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "Intended Audience :: Science/Research",
        "Topic :: Text Processing :: Linguistic",
        "Topic :: Software Development :: Libraries :: Python Modules",
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
    install_requires=[
    ],
)
